@@ -6,7 +6,7 @@ var _pro_s_h_a_d_e__distances_8hpp =
     [ "computeEMatricesForLM", "_pro_s_h_a_d_e__distances_8hpp.html#a8ed62a245d4fa9750f98b60d755b61c1", null ],
     [ "computeEnergyLevelsDescriptor", "_pro_s_h_a_d_e__distances_8hpp.html#a1a977a344baa3b1697743060789bceb5", null ],
     [ "computeInverseSOFTTransform", "_pro_s_h_a_d_e__distances_8hpp.html#a3cdde76bf20d9cd5d756ffde2d3dc854", null ],
-    [ "computeRotationunctionDescriptor", "_pro_s_h_a_d_e__distances_8hpp.html#a0f062b77c4b5360a17249e74e6a15538", null ],
+    [ "computeRotationFunctionDescriptor", "_pro_s_h_a_d_e__distances_8hpp.html#ab5b11e10f0f11541ebb8deeaa427700d", null ],
     [ "computeRRPPearsonCoefficients", "_pro_s_h_a_d_e__distances_8hpp.html#acde4bb62c09903a347ecde6f0a5302b1", null ],
     [ "computeSphericalHarmonicsMagnitude", "_pro_s_h_a_d_e__distances_8hpp.html#a22db876a8cca08073f4db031996f537b", null ],
     [ "computeTraceSigmaDescriptor", "_pro_s_h_a_d_e__distances_8hpp.html#a34bad8d846082de4dc61870d67e762cf", null ],
