@@ -1,6 +1,8 @@
 var hierarchy =
 [
     [ "ProSHADE_internal_maths::BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", null ],
+    [ "ProSHADE_internal_precomputedVals::icosahedronAxes", "class_pro_s_h_a_d_e__internal__precomputed_vals_1_1icosahedron_axes.html", null ],
+    [ "ProSHADE_internal_precomputedVals::octahedronAxes", "class_pro_s_h_a_d_e__internal__precomputed_vals_1_1octahedron_axes.html", null ],
     [ "ProSHADE_internal_data::ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html", null ],
     [ "ProSHADE_internal_maths_bicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths__bicubic_interpolator.html", null ],
     [ "ProSHADE_internal_spheres::ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", null ],
@@ -10,5 +12,6 @@ var hierarchy =
     [ "ProSHADE_internal_spheres::ProSHADE_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__sphere.html", null ],
     [ "runtime_error", null, [
       [ "ProSHADE_exception", "class_pro_s_h_a_d_e__exception.html", null ]
-    ] ]
+    ] ],
+    [ "ProSHADE_internal_precomputedVals::tetrahedronAxes", "class_pro_s_h_a_d_e__internal__precomputed_vals_1_1tetrahedron_axes.html", null ]
 ];
\ No newline at end of file
