@@ -19,8 +19,8 @@
 #
 #   \author    Michal Tykac
 #   \author    Garib N. Murshudov
-#   \version   0.7.6.1
-#   \date      AUG 2021
+#   \version   0.7.6.2
+#   \date      DEC 2021
 ######################################################
 ######################################################
 
@@ -74,6 +74,7 @@ ps.setEnLevShellWeight                                ( 1.0 )
 
 ######################################################
 ### All other (possibly other tasks related) settings
+ps.setSymmetryCentreSearch                            ( False )                                                          # Should symmetry centre be searched for? Takes a lot of time...
 ps.setBicubicInterpolationSearch                      ( True )                                                           # Should bi-cubic interpolation between peak grid indices be done?
 ps.setMaxSymmetryFold                                 ( 30 )                                                             # The maximum prime number fold that will be searched for.
 ps.setFSCThreshold                                    ( 0.75 )                                                           # The threshold for FSC value under which the axis is considered to be likely noise.
@@ -116,9 +117,9 @@ print                                                 ( "Full rotation function
 
 ######################################################
 ### Expected output
-#   Energy levels distance          : 0.85850143       0.58064646
-#   Trace sigma distance            : 0.9622864        0.75547904
-#   Full rotation function distance : 0.6247927        0.47406107
+#   Energy levels distance          : 0.8556063        0.5606434
+#   Trace sigma distance            : 0.96467125        0.7530951
+#   Full rotation function distance : 0.62452674        0.46518552
 
 ######################################################
 ### Release memory
