@@ -15,8 +15,8 @@
     
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.1
-    \date      AUG 2021
+    \version   0.7.6.2
+    \date      DEC 2021
 */
 
 //==================================================== ProSHADE
@@ -66,8 +66,9 @@ void ProSHADE_internal_messages::printTerminateMessage ( proshade_signed verbose
     \param[in] verbose Int value stating how loud the user requested the ProSHADE run to be.
     \param[in] messageLevel Int value stating how important the message is.
     \param[in] message String of the actual message to be displayed.
+    \param[in] messageShift How much should  the message be shifted (i.e. if this a sub-process of larger task, set this to 1 instead of 0).
  */
-void ProSHADE_internal_messages::printProgressMessage ( proshade_signed verbose, proshade_signed messageLevel, std::string message )
+void ProSHADE_internal_messages::printProgressMessage ( proshade_signed verbose, proshade_signed messageLevel, std::string message, proshade_signed messageShift )
 {
     if ( verbose >= messageLevel )
     {
@@ -76,7 +77,7 @@ void ProSHADE_internal_messages::printProgressMessage ( proshade_signed verbose,
             std::cout << " ";
         }
         
-        for ( proshade_signed iter = 0; iter < messageLevel; iter++ )
+        for ( proshade_signed iter = 0; iter < ( messageLevel + messageShift ); iter++ )
         {
             std::cout << "... ";
         }
@@ -209,6 +210,10 @@ void ProSHADE_internal_messages::printHelp [[noreturn]] ( void )
     std::cout << "            internal map representation in order to avoid clashes with          " << std::endl;
     std::cout << "            adjacent cells.                                                     " << std::endl;
     std::cout << "                                                                                " << std::endl;
+    std::cout << "    -H or --coordExtraSpace                         [DEFAULT:         10.0]     " << std::endl;
+    std::cout << "            The extra space added to any co-ordinates before computing their    " << std::endl;
+    std::cout << "            theoretical density map to make sure no atom is at the boundary.    " << std::endl;
+    std::cout << "                                                                                " << std::endl;
     std::cout << "    -i or --integOrder                              [DEFAULT:         AUTO]     " << std::endl;
     std::cout << "            The order to which the Gauss-Legendre integration should be         " << std::endl;
     std::cout << "            computed to. For automatic determination use 0.                     " << std::endl;
@@ -301,11 +306,11 @@ void ProSHADE_internal_messages::printHelp [[noreturn]] ( void )
     std::cout << "            The minimum average peak height for symmetry axis to be still       " << std::endl;
     std::cout << "            considered as \"real\" for the symmetry detection.                    " << std::endl;
     std::cout << "                                                                                " << std::endl;
-    std::cout << "    --fscThres or -C                               [DEFAULT:          0.75]     " << std::endl;
+    std::cout << "    --fscThres or -C                               [DEFAULT:          0.33]     " << std::endl;
     std::cout << "            The Fourier Shell Correlation value the axes need to achieve in     " << std::endl;
     std::cout << "            order to be considered \"real\" by the symmetry detection algorithm.  " << std::endl;
     std::cout << "                                                                                " << std::endl;
-    std::cout << "    --peakMinThres or -E                           [DEFAULT:          0.80]     " << std::endl;
+    std::cout << "    --peakMinThres or -E                           [DEFAULT:          0.75]     " << std::endl;
     std::cout << "            The average peak height value the axes need to achieve in order     " << std::endl;
     std::cout << "            to be considered \"possible\" by the symmetry detection algorithm.    " << std::endl;
     std::cout << "                                                                                " << std::endl;
@@ -387,7 +392,10 @@ void ProSHADE_internal_messages::printHelp [[noreturn]] ( void )
     std::cout << "    --noFRF or -n                                   [DEFAULT:         TRUE]     " << std::endl;
     std::cout << "            Is the computation of the full rotation function descriptor         " << std::endl;
     std::cout << "            required?                                                           " << std::endl;
-    std::cout << "                                                                                " << std::endl;
+    std::cout << "                                                    [DEFAUlT:        FALSE]     " << std::endl;
+    std::cout << "    -I or --symCentre                                                           " << std::endl;
+    std::cout << "            Should symmetry centre be sought using phaseless map symmetry       " << std::endl;
+    std::cout << "            before symmetry detection task is done?                             " << std::endl;
     std::cout << std::endl << std::flush;
     
     //================================================ Done
