@@ -16,8 +16,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.1
-    \date      AUG 2021
+    \version   0.7.6.2
+    \date      DEC 2021
  */
 
 //==================================================== ProSHADE
@@ -49,6 +49,7 @@ namespace ProSHADE_internal_misc
             
     bool sortSymHlp                                   ( const proshade_double* a, const proshade_double* b );
     bool sortSymHlpInv                                ( const proshade_double* a, const proshade_double* b );
+    bool sortISymByPeak                               ( const std::vector< proshade_double* > a, const std::vector< proshade_double* > b );
     bool sortDSymHlpInv                               ( const proshade_double* a, const proshade_double* b );
     bool sortSymFoldHlp                               ( const proshade_double* a, const proshade_double* b );
     bool sortSymInvFoldHlp                            ( const proshade_double* a, const proshade_double* b );
