@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.1
-    \date      AUG 2021
+    \version   0.7.6.2
+    \date      DEC 2021
  */
 
 //==================================================== ProSHADE
@@ -34,48 +34,6 @@
  */
 namespace ProSHADE_internal_symmetry
 {
-    std::vector< proshade_double* > getPeaksAngleAxisPositions ( std::vector< proshade_double* > allPeaks, proshade_signed verbose );
-    std::vector< proshade_double > findPeaksByHeightBoundaries ( std::vector< proshade_double* > allPeaks, proshade_double smoothing );
-    std::vector< std::vector< proshade_unsign > > findPeaksCSymmetry ( std::vector< proshade_double* >* peaks, proshade_signed verbose,
-                                                                       proshade_unsign band, proshade_double missPeakThres, proshade_double axisErrTolerance,
-                                                                       bool axisErrToleranceDef, ProSHADE_internal_data::ProSHADE_data* dataObj );
-    std::vector< std::vector< proshade_unsign > > groupSameAxes ( std::vector< proshade_double* >& peaks, proshade_double errTolerance );
-    void giveOppositeAxesSameDirection                ( std::vector< proshade_double* > peaks );
-    void printSymmetryPeaks                           ( std::vector< proshade_unsign > grp, std::vector< proshade_double* > peaks,
-                                                        proshade_signed verbose, proshade_unsign groupNo );
-    bool smallestDistanceBetweenAngles                ( std::vector< proshade_unsign > grp, std::vector< proshade_double* > peaks,
-                                                        std::vector< proshade_double >* tried, proshade_double* dist );
-    void addZeroPeakToGroups                          ( std::vector< std::vector< proshade_unsign > >& grpsVec,
-                                                        std::vector< proshade_double* >& peaks );
-    bool determineFoldToTry                           ( proshade_double dist, proshade_double* divBasis, proshade_double* divRem,
-                                                        proshade_double peakErr, proshade_double* symmErr,
-                                                        std::vector< proshade_unsign >* angsToTry );
-    void findExpectedPeakRotations                    ( proshade_unsign fold, std::vector< proshade_double >* expAngs );
-    proshade_unsign checkExpectedAgainstFound         ( std::vector< proshade_unsign > grp, std::vector< proshade_double* > peaks,
-                                                        std::vector< proshade_double >* expAngs, std::vector< proshade_unsign >* matchedAngs,
-                                                        std::vector< proshade_unsign >* missingAngs, proshade_double axisTol );
-    proshade_double checkForMissingPeak               ( ProSHADE_internal_data::ProSHADE_data* dataObj, proshade_double x, proshade_double y,
-                                                        proshade_double z, proshade_double angle, proshade_double heightThres,
-                                                        proshade_double axTol );
-    void saveDetectedCSymmetry                        ( proshade_unsign fold, std::vector< proshade_unsign >* matchedPeaks,
-                                                        std::vector< std::vector< proshade_unsign > >* ret, proshade_signed verbose );
-    bool completeMissingCSymmetry                     ( ProSHADE_internal_data::ProSHADE_data* dataObj, proshade_unsign fold,
-                                                        std::vector< proshade_unsign >* grp, std::vector< proshade_double* >* peaks,
-                                                        std::vector< proshade_unsign >* missingPeaks,
-                                                        std::vector< proshade_double >* expectedAngles,
-                                                        std::vector< proshade_unsign >* matchedPeaks, proshade_double axErrTolerance,
-                                                        proshade_signed verbose );
-    void findSymmetryUsingFold                        ( ProSHADE_internal_data::ProSHADE_data* dataObj, std::vector< proshade_unsign >* angsToTry,
-                                                        std::vector< proshade_unsign >* grp, std::vector< proshade_double* >* peaks,
-                                                        std::vector< std::vector< proshade_unsign > >* ret,
-                                                        std::vector< proshade_unsign >* testedAlready, proshade_double axErrTolerance, bool axErrToleranceDefault,
-                                                        proshade_double missPeakThres, proshade_signed verbose );
-    void printSymmetryGroup                           ( std::vector< proshade_unsign > grp, std::vector< proshade_double* > peaks,
-                                                        proshade_signed verbose );
-    void printSymmetryCompletion                      ( proshade_unsign noSyms, proshade_signed verbose );
-    void saveAllCSymmetries                           ( std::vector< std::vector< proshade_unsign > > detected,
-                                                        std::vector< proshade_double* > peaks, std::vector< proshade_double* >* ret,
-                                                        proshade_double axErr );
     bool isSymmetrySame                               ( std::vector< proshade_double* >* ret, proshade_double* sym, proshade_double simThres, proshade_signed* matchedPos );
     bool isSymmetrySame                               ( std::vector< proshade_double* >* ret, proshade_double* sym, proshade_double simThres, proshade_signed* matchedPos, proshade_double fscVal );
     void saveDSymmetry                                ( std::vector< proshade_double* >* ret, std::vector< proshade_double* >* CSymList,
@@ -83,7 +41,7 @@ namespace ProSHADE_internal_symmetry
     bool detectTetrahedralSymmetry                    ( std::vector< proshade_double* >* CSymList, proshade_double axErr, proshade_double minPeakHeight );
     void findTetra4C3s                                ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     bool testGroupAgainstSymmetry                     ( std::vector< proshade_double* >* CSymList, std::vector< proshade_unsign >* grp,
                                                         proshade_double* sym, proshade_double axErr, proshade_double angle, bool improve,
                                                         proshade_unsign pos = 0 );
@@ -104,20 +62,20 @@ namespace ProSHADE_internal_symmetry
                                                         proshade_double minPeakHeight );
     void findTetra3C2s                                ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     bool testGroupAgainstGroup                        ( std::vector< proshade_double* >* CSymList, std::vector< proshade_unsign >* grp1,
                                                         std::vector< proshade_double* >* RetList, std::vector< proshade_unsign >* grp2,
                                                         proshade_double angle, proshade_double axErr );
     bool detectOctahedralSymmetry                     ( std::vector< proshade_double* >* CSymList, proshade_double axErr, proshade_double minPeakHeight );
     void findOcta3C4s                                 ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     void findOcta4C3s                                 ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     void findOcta6C2s                                 ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     bool findMissingAxesDual                          ( std::vector< proshade_unsign >* possibilities,
                                                         std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret, std::vector<
                                                         proshade_unsign >* retGroup, proshade_unsign requiredNoAxes, proshade_double axErr,
@@ -135,13 +93,13 @@ namespace ProSHADE_internal_symmetry
     bool detectIcosahedralSymmetry                    ( std::vector< proshade_double* >* CSymList, proshade_double axErr, proshade_double minPeakHeight );
     void findIcos6C5s                                 ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     void findIcos10C3s                                ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     void findIcos15C2s                                ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret,
                                                         proshade_double axErr, ProSHADE_internal_data::ProSHADE_data* dataObj,
-                                                        proshade_signed verbose, proshade_double minPeakHeight );
+                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double minPeakHeight );
     bool findMissingAxesTriple                        ( std::vector< proshade_unsign >* possibilities,
                                                         std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret, std::vector<
                                                         proshade_unsign >* retGroup, proshade_unsign requiredNoAxes, proshade_double axErr,
@@ -156,9 +114,24 @@ namespace ProSHADE_internal_symmetry
                                                         ProSHADE_internal_data::ProSHADE_data* dataObj );
     proshade_double findPredictedSingleAxisHeight     ( proshade_double* axis, proshade_double fold, ProSHADE_internal_data::ProSHADE_data* dataObj, ProSHADE_settings* settings );
     void findPredictedAxesHeights                     ( std::vector< proshade_double* >* ret, ProSHADE_internal_data::ProSHADE_data* dataObj, ProSHADE_settings* settings );
+    void optimiseDGroupAngleFromAxesHeights           ( std::vector < std::vector< proshade_double > >* ret, ProSHADE_internal_data::ProSHADE_data* dataObj, ProSHADE_settings* settings );
+    void optimiseDGroupAngleFromAxesHeights           ( std::vector < std::vector< proshade_double > >* allCs, std::vector< proshade_unsign > selection, ProSHADE_internal_data::ProSHADE_data* dataObj,
+                                                        ProSHADE_settings* settings );
     void predictIcosAxes                              ( std::vector< proshade_double* >* CSymList, std::vector< std::vector< proshade_double* > >* ret, proshade_double axErr, proshade_double minPeakHeight );
     void predictOctaAxes                              ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret, proshade_double axErr, proshade_double minPeakHeight );
     void predictTetraAxes                             ( std::vector< proshade_double* >* CSymList, std::vector< proshade_double* >* ret, proshade_double axErr, proshade_double minPeakHeight );
+    std::vector< proshade_unsign > findReliableUnphasedSymmetries ( std::vector < std::vector< proshade_double > >* allCs, proshade_signed verbose, proshade_signed messageShift, proshade_double tolerance );
+    void allocateCentreOfMapFourierTransforms         ( proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim, fftw_complex *&origMap, fftw_complex *&origCoeffs, fftw_complex *&rotMapComplex,
+                                                        fftw_complex *&rotCoeffs, fftw_complex *&trFunc, fftw_complex *&trFuncCoeffs, fftw_plan *planForwardFourier, fftw_plan *planForwardFourierRot,
+                                                        fftw_plan *planReverseFourierComb );
+    void releaseCentreOfMapFourierTransforms          ( fftw_complex *origMap, fftw_complex *origCoeffs, fftw_complex *rotMapComplex, fftw_complex *rotCoeffs, fftw_complex *trFunc, fftw_complex *trFuncCoeffs,
+                                                        fftw_plan planForwardFourier, fftw_plan planForwardFourierRot, fftw_plan planReverseFourierComb );
+    std::vector< proshade_double > findTranslationBetweenRotatedAndOriginalMap ( ProSHADE_internal_data::ProSHADE_data* symStr, std::vector < proshade_double > symElem, fftw_complex *origCoeffs,
+                                                                                 fftw_complex* rotMapComplex, fftw_complex* rotCoeffs, fftw_plan planForwardFourierRot, fftw_complex* trFuncCoeffs,
+                                                                                 fftw_complex* trFunc, fftw_plan planReverseFourierComb );
+    std::vector< proshade_double > findPointFromTranslations ( ProSHADE_internal_data::ProSHADE_data* symStr, std::vector < std::vector < proshade_double > > symElems, fftw_complex *origCoeffs,
+                                                               fftw_complex* rotMapComplex, fftw_complex* rotCoeffs, fftw_plan planForwardFourierRot, fftw_complex* trFuncCoeffs,
+                                                               fftw_complex* trFunc, fftw_plan planReverseFourierComb );
 }
 
 #endif
