@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.1
-    \date      JUL 2021
+    \version   0.7.6.2
+    \date      DEC 2021
  */
 
 //==================================================== ProSHADE
@@ -187,7 +187,7 @@ void ProSHADE_internal_wigner::prepareTrigsSqrtsAndExponents ( proshade_double*
 void ProSHADE_internal_wigner::computeWignerMatrices ( ProSHADE_settings* settings, ProSHADE_internal_data::ProSHADE_data* obj, proshade_double* alphaExponentReal, proshade_double* alphaExponentImag, proshade_double* gammaExponentReal, proshade_double* gammaExponentImag, proshade_double* matIn, proshade_double* matOut, proshade_double* trigs, proshade_double* sqrts, proshade_double* workspace )
 {
     //================================================ Report progress
-    ProSHADE_internal_messages::printProgressMessage  ( settings->verbose, 4, "Start Wigner D matrix computation." );
+    ProSHADE_internal_messages::printProgressMessage  ( settings->verbose, 4, "Start Wigner D matrix computation.", settings->messageShift );
     
     //================================================ For each band, find the Wigned d matrix
     proshade_double *expARStart, *expAIStart, *expGRStart, *expGIStart;
@@ -236,7 +236,7 @@ void ProSHADE_internal_wigner::computeWignerMatrices ( ProSHADE_settings* settin
     }
     
     //================================================ Report progress
-    ProSHADE_internal_messages::printProgressMessage  ( settings->verbose, 5, "Wigner D matrices obtained." );
+    ProSHADE_internal_messages::printProgressMessage  ( settings->verbose, 5, "Wigner D matrices obtained.", settings->messageShift );
 
     //================================================ Done
     return ;
