@@ -14,8 +14,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.1
-    \date      AUG 2021
+    \version   0.7.6.2
+    \date      DEC 2021
  */
 
 //==================================================== Do not use the following flags for the included files - this causes a lot of warnings that have nothing to do with ProSHADE
@@ -105,6 +105,7 @@ PYBIND11_MAKE_OPAQUE                                  ( std::vector < std::strin
 #include "pyProSHADE.cpp"
 #include "pyProSHADE_data.cpp"
 #include "pyProSHADE_distances.cpp"
+#include "pyProSHADE_maths.cpp"
 
 //==================================================== Declare the exported functions
 PYBIND11_MODULE ( proshade, pyProSHADE )
@@ -131,4 +132,5 @@ PYBIND11_MODULE ( proshade, pyProSHADE )
     add_settingsClass                                 ( pyProSHADE );
     add_dataClass                                     ( pyProSHADE );
     add_distancesClass                                ( pyProSHADE );
+    add_mathsNamespace                                ( pyProSHADE );
 }
